/*
Alternate CMYK Spot Channel Values scriptUI GUI.jsx
v1.0 - 22nd October 2024, Stephen Marsh
https://community.adobe.com/t5/photoshop-ecosystem-discussions/how-to-convert-pantone-in-photoshop-in-the-way-i-need-what-is-my-mistake/td-p/14908470
*/

#target photoshop

// Create the main window
var dlg = new Window("dialog", "Alternate CMYK Spot Channel Values");
dlg.orientation = "column";
dlg.alignChildren = ["fill", "top"];
dlg.preferredSize.width = 300;

// Create main group for CMYK values
var cmykGroup = dlg.add("panel", undefined, "CMYK Values");
cmykGroup.orientation = "column";
cmykGroup.alignChildren = ["left", "top"];
cmykGroup.margins = 20;
cmykGroup.spacing = 12;

// Create grid rows for each CMYK value
// Cyan Row
var cyanRow = cmykGroup.add("group");
cyanRow.orientation = "row";
cyanRow.alignChildren = ["left", "center"];
cyanRow.spacing = 5;
var cyanLabel = cyanRow.add("group");
cyanLabel.preferredSize.width = 60;
cyanLabel.orientation = "row";
cyanLabel.alignChildren = ["left", "center"];
cyanLabel.add("statictext", undefined, "Cyan:");
var cyanInput = cyanRow.add("edittext", undefined, "");
cyanInput.preferredSize.width = 50;

// Magenta Row
var magentaRow = cmykGroup.add("group");
magentaRow.orientation = "row";
magentaRow.alignChildren = ["left", "center"];
magentaRow.spacing = 5;
var magentaLabel = magentaRow.add("group");
magentaLabel.preferredSize.width = 60;
magentaLabel.orientation = "row";
magentaLabel.alignChildren = ["left", "center"];
magentaLabel.add("statictext", undefined, "Magenta:");
var magentaInput = magentaRow.add("edittext", undefined, "");
magentaInput.preferredSize.width = 50;

// Yellow Row
var yellowRow = cmykGroup.add("group");
yellowRow.orientation = "row";
yellowRow.alignChildren = ["left", "center"];
yellowRow.spacing = 5;
var yellowLabel = yellowRow.add("group");
yellowLabel.preferredSize.width = 60;
yellowLabel.orientation = "row";
yellowLabel.alignChildren = ["left", "center"];
yellowLabel.add("statictext", undefined, "Yellow:");
var yellowInput = yellowRow.add("edittext", undefined, "");
yellowInput.preferredSize.width = 50;

// Black Row
var blackRow = cmykGroup.add("group");
blackRow.orientation = "row";
blackRow.alignChildren = ["left", "center"];
blackRow.spacing = 5;
var blackLabel = blackRow.add("group");
blackLabel.preferredSize.width = 60;
blackLabel.orientation = "row";
blackLabel.alignChildren = ["left", "center"];
blackLabel.add("statictext", undefined, "Black:");
var blackInput = blackRow.add("edittext", undefined, "");
blackInput.preferredSize.width = 50;

// Checkbox for merging the spot channel
var mergeCheckbox = dlg.add("checkbox", undefined, "Merge the selected spot channel");

// Create button group
var buttonGroup = dlg.add("group");
buttonGroup.orientation = "row";
buttonGroup.alignChildren = ["right", "center"];
buttonGroup.alignment = ["right", "top"];
var cancelButton = buttonGroup.add("button", undefined, "Cancel");
var okButton = buttonGroup.add("button", undefined, "OK", { name: "ok" });

// Add button click handlers
cancelButton.onClick = function () {
    dlg.close();
};
okButton.onClick = function () {
    try {
        if (!app.documents.length) {
            alert("No active document found.");
            return;
        }
        var activeDoc = app.activeDocument;

        if (!activeDoc.activeChannels.length) {
            alert("No active channel found.");
            return;
        }
        var activeChannel = activeDoc.activeChannels[0];

        if (activeChannel.kind !== ChannelType.SPOTCOLOR) {
            alert("The active channel is NOT a Spot Color channel!");
            return;
        }

        var idset = stringIDToTypeID("set");
        var desc371 = new ActionDescriptor();
        var idnull = stringIDToTypeID("null");
        var ref28 = new ActionReference();
        var idchannel = stringIDToTypeID("channel");
        var idordinal = stringIDToTypeID("ordinal");
        var idtargetEnum = stringIDToTypeID("targetEnum");
        ref28.putEnumerated(idchannel, idordinal, idtargetEnum);
        desc371.putReference(idnull, ref28);
        var idto = stringIDToTypeID("to");
        var desc372 = new ActionDescriptor();
        var idcolor = stringIDToTypeID("color");
        var desc373 = new ActionDescriptor();
        // Use values from input fields
        var idcyan = stringIDToTypeID("cyan");
        desc373.putDouble(idcyan, Number(cyanInput.text));
        var idmagenta = stringIDToTypeID("magenta");
        desc373.putDouble(idmagenta, Number(magentaInput.text));
        var idyellowColor = stringIDToTypeID("yellowColor");
        desc373.putDouble(idyellowColor, Number(yellowInput.text));
        var idblack = stringIDToTypeID("black");
        desc373.putDouble(idblack, Number(blackInput.text));
        var idCMYKColorClass = stringIDToTypeID("CMYKColorClass");
        desc372.putObject(idcolor, idCMYKColorClass, desc373);
        var idspotColorChannel = stringIDToTypeID("spotColorChannel");
        desc371.putObject(idto, idspotColorChannel, desc372);
        executeAction(idset, desc371, DialogModes.NO);

        if (mergeCheckbox.value) {
            executeAction(stringIDToTypeID("mergeSpotChannel"), undefined, DialogModes.NO);
        }

        dlg.close();

    } catch (e) {
        alert("Error updating color: " + e);
    }
};

// Show the window
dlg.show();